===============
Release Changes
===============

**v0.4.5**
- minor packaging changes
- added initial suppor for object reload based on age

**v0.4.4**
- Reorganized for easier packaging
- Supporting both Python2 and Python3 in the installer
- tox automated virtenv & tests for python 2.6, 2.7, 3.2
- Added command line monitoring script

**v0.4.1** 
- Changing project name to better fit PyPi
- Packaging as an installable module


**v0.4**
- Added basic nose test script
- Refactored classes
- Added Alerts() class 
- Optional json output (getting ready for web service/api)
- Various code cleanup/improvements


**v0.3.1**
- bugfix only


**v0.3:**
- refactored nagios plugin, it now uses (only) SAME code(s) 
- Moved SAME code related methods to new class which can be used without parsing an alerts feed.  


**v0.2:**
- moved master branch to python 3.x
- maintaining python2.x branch

**v0.1:**
- First tagged release
